@@ -25,7 +25,7 @@
 *   59 Temple Place, Suite 330, Boston, MA 02111-1307, USA
 * ؼ񤤤Ƥ
 * 
-* $Id: amenu.h,v 1.12 2007/05/11 00:42:16 bowkenken Exp $
+* $Id: amenu.h,v 1.14 2007/06/05 07:33:35 bowkenken Exp $
 ***************************************************************/
 
 #ifndef	AMENU_H
@@ -41,7 +41,9 @@
 #define	AUTO_MARK_MAX_N	(AUTO_MARK_N_PER_PAGE * AUTO_MARK_PAGE_N)
 
 /* ȥκʸ */
-#define	MSG_TTL_AUTO_MARK_MAX_LEN	128
+#define	MSG_TTL_AUTO_MARK_MAX_LEN	64
+#define	MSG_TTL_AUTO_MARK_INFO_MAX_LEN	30
+#define	MSG_TTL_AUTO_MARK_HINT_MAX_LEN	30
 
 /* ƥμκ */
 #define	AUTO_MARK_APPOINT_ITEM_MAX_N	64
