@@ -13,16 +13,22 @@ void	call_gui_message_set_flag_more( bool_t flag );
 void	call_gui_message_draw( void );
 void	call_gui_num_draw( long *n, long min, long max, long figure );
 void	call_gui_num_wipe( void );
+void	call_gui_input_string_draw(
+	const char *ttl, const char *str, long len
+);
+void	call_gui_input_string_wipe( void );
 void	set_str_dir_sel_graph( char *dir );
 void	call_pcg_dun_reset( void );
 void	call_pcg_dun_reset_update_flg( void );
 void	call_pcg_dun_draw( long map_x, long map_y, long map_w, long map_h );
 void	call_pcg_dun_scroll( long map_x, long map_y );
-long	call_pcg_dun_get_chr_draw_left( chr_t *chr, bool_t flag_one_draw );
-long	call_pcg_dun_get_chr_draw_right( chr_t *chr, bool_t flag_one_draw );
-long	call_pcg_dun_get_chr_draw_top( chr_t *chr, bool_t flag_one_draw );
-long	call_pcg_dun_get_chr_draw_bottom( chr_t *chr, bool_t flag_one_draw );
+long	call_pcg_dun_get_chr_draw_left( chr_t *chr, bool_t flagPre );
+long	call_pcg_dun_get_chr_draw_right( chr_t *chr, bool_t flagPre );
+long	call_pcg_dun_get_chr_draw_top( chr_t *chr, bool_t flagPre );
+long	call_pcg_dun_get_chr_draw_bottom( chr_t *chr, bool_t flagPre );
 bool_t	call_pcg_dun_clip_win( long mapX, long mapY );
+bool_t	call_pcg_dun_clip_win_x( long mapX );
+bool_t	call_pcg_dun_clip_win_y( long mapY );
 void	call_stat_win_redraw( void );
 long	call_key_get_char( void );
 
