@@ -149,6 +149,9 @@ char	*get_reg_macro( void );
 void	set_reg_macro( bool_t flg );
 void	reg_macro( long c );
 void	draw_replay( bool_t flg_redraw );
+bool_t	get_key_pos( pos_t *pos );
+long	get_key_num( void );
+void	un_get_key( long c );
 long	get_key( bool_t flg_clr_key_buf );
 void	get_key_wait_cancel( bool_t flg_clr_key_buf );
 long	get_key_sub_1( bool_t flg_clr_key_buf );
