@@ -25,7 +25,7 @@
 *   59 Temple Place, Suite 330, Boston, MA 02111-1307, USA
 * ؼ񤤤Ƥ
 * 
-* $Id: dun.c,v 1.104 2007/05/21 05:40:12 bowkenken Exp $
+* $Id: dun.c,v 1.106 2007/06/07 02:29:25 bowkenken Exp $
 ***************************************************************/
 
 /***************************************************************
@@ -321,6 +321,15 @@ bool_t	set_crsr_ptn( crsr_ptn_t *dst, crsr_ptn_t *src )
 	return TRUE;
 }
 
+/***************************************************************
+* µܤ겼ꤷƳ˵
+***************************************************************/
+
+void	up_dun_town( void )
+{
+	up_dun( -dun.lev );
+}
+
 /***************************************************************
 * µܤ겼ꤹ
 * long d : 곬(+)곬(-)
@@ -372,9 +381,6 @@ void	up_dun( long d )
 		}
 	}
 
-	for( i = 0; i < MBR_MAX_N; i++ )
-		clr_chr_trgt_act( pty->mbr[i], FALSE );
-
 	reset_all( TRUE );
 }
 
@@ -397,6 +403,12 @@ void	reset_all_save( bool_t flg_appear )
 
 void	reset_all( bool_t flg_appear )
 {
+	party_t	*pty = get_party();
+	long	i;
+
+	for( i = 0; i < MBR_MAX_N; i++ )
+		clr_chr_trgt_act( pty->mbr[i], FALSE );
+
 	bgn_nest_flg( g_nest_flg_dun );
 
 	reset_trap();
@@ -3464,10 +3476,14 @@ bool_t	chk_mark_door( door_t *p, act_kind_t act_kind )
 
 bool_t	up_stairs( void )
 {
+	if( !chk_party_no_mbr( FALSE ) )
+		return FALSE;
+
 	if( !chk_stairs( FACE_MJR_STAIRS_UP ) ){
 		print_msg( FLG_NULL, MSG_ERR_STAIRS_UP );
 		return FALSE;
 	}
+
 	print_msg( FLG_NULL, MSG_UP_DUN );
 	up_dun( +1 );
 
@@ -3481,10 +3497,14 @@ bool_t	up_stairs( void )
 
 bool_t	down_stairs( void )
 {
+	if( !chk_party_no_mbr( FALSE ) )
+		return FALSE;
+
 	if( !chk_stairs( FACE_MJR_STAIRS_DOWN ) ){
 		print_msg( FLG_NULL, MSG_ERR_STAIRS_DOWN );
 		return FALSE;
 	}
+
 	print_msg( FLG_NULL, MSG_DOWN_DUN );
 	up_dun( -1 );
 
