@@ -25,7 +25,7 @@
 *   59 Temple Place, Suite 330, Boston, MA 02111-1307, USA
 * ؼ񤤤Ƥ
 * 
-* $Id: fight.c,v 1.121 2007/01/11 17:31:34 bowkenken Exp $
+* $Id: fight.c,v 1.122 2007/05/20 15:54:43 bowkenken Exp $
 ***************************************************************/
 
 /***************************************************************
@@ -57,6 +57,9 @@
 * ٥ɶζδ
 ***************************************************************/
 
+/* ¦䤹 */
+#define	HIT_ADJ_RATE	((rate_t)150)
+
 #define	HIT_FIT_AVE_N	10
 #define	HIT_HNT_AVE_N	10
 #define	WPN_CRTCL_FIT_AVE_N	20
@@ -72,27 +75,27 @@
 #define	DEF_MON_ADD	0
 
 /* դΥƥ롦ҥåΨ */
-#define	WPN_CRTCL_THF_LEV_RATE	30
-#define	WPN_CRTCL_THF_MAX_RATE	30
+#define	WPN_CRTCL_THF_LEV_RATE	((rate_t)30)
+#define	WPN_CRTCL_THF_MAX_RATE	((rate_t)30)
 
 /* ǦԤμڤΨ */
-#define	NINJA_CRTCL_RATE	150
+#define	NINJA_CRTCL_RATE	((rate_t)150)
 
-#define	DEF_MIN_RATE	30
+#define	DEF_MIN_RATE	((rate_t)30)
 #define	DEF_AVE_N	10
 #define	ARMOR_CRTCL_AVE_N	10
 #define	AC_AVE_N	20
 
 /* ɸ(⤷Ƥʤ)ɸϥåΨ */
-#define	DEF_DEF_RATE	150
-#define	DEF_AC_RATE	150
+#define	DEF_DEF_RATE	((rate_t)150)
+#define	DEF_AC_RATE	((rate_t)150)
 
 /* ˡξι */
-#define	DAM_STICK_RATE	((rate_t)120)
+#define	DAM_STICK_RATE	((rate_t)300)
 #define	DAM_STICK_ADD	10
 
 /* ʸι */
-#define	DAM_SPELL_RATE	((rate_t)150)
+#define	DAM_SPELL_RATE	((rate_t)300)
 #define	DAM_SPELL_ADD	10
 
 /* ֥Ȥɸ */
@@ -1739,6 +1742,8 @@ long	get_hit( chr_t *p, const attack_t *attack )
 
 #endif	/* FLG_ITEM_ADD_RATE */
 
+	hit = hit * HIT_ADJ_RATE / _100_PERCENT;
+
 	if( hit < 1 )
 		hit = 1;
 
