@@ -503,10 +503,20 @@ bool_t	save_game_data_cnf_contents(
 );
 bool_t	save_game_replay( void );
 bool_t	save_game_replay_slot( long n );
+bool_t	save_bug_repo_replay( void );
+bool_t	copy_file_bug_repo( void );
 bool_t	save_game_replay_ver_1( const ver_t *ver, long n );
 bool_t	save_game_replay_contents(
 	FILE *fp, const ver_t *ver, long n
 );
+void	get_path_game_data_txt( char *path, long n );
+void	get_path_game_data_bin( char *path, long n );
+void	get_path_game_data_cnf( char *path, long n );
+void	get_path_game_data_rep( char *path, long n );
+void	get_path_bug_repo_txt( char *path );
+void	get_path_bug_repo_bin( char *path );
+void	get_path_bug_repo_cnf( char *path );
+void	get_path_bug_repo_rep( char *path );
 FILE	*open_game_data( char type, long n, bool_t flg_txt );
 FILE	*open_game_data_cnf( char type, long n );
 FILE	*open_game_replay( char type, long n );
@@ -622,6 +632,7 @@ fx_kind_t	trans_idx_to_fx_kind( long idx );
 long	trans_fx_kind_to_idx( fx_kind_t k );
 request_kind_t	trans_idx_to_request_kind( long idx );
 long	trans_request_kind_to_idx( request_kind_t k );
+bool_t	copy_file( const char *src, const char *dst );
 char	*cat_path( char *path, char *file );
 bool_t	chk_exist_file( char *s );
 bool_t	chk_exist_dir( char *s );
