@@ -25,7 +25,7 @@
 *   59 Temple Place, Suite 330, Boston, MA 02111-1307, USA
 * ؼ񤤤Ƥ
 * 
-* $Id: gfile.h,v 1.13 2007/03/17 21:57:07 bowkenken Exp $
+* $Id: gfile.h,v 1.14 2007/06/03 04:37:48 bowkenken Exp $
 ***************************************************************/
 
 #ifndef	GFILE_H
@@ -39,6 +39,8 @@
 #define	SAVE_N_SEL	-1
 /* ư֡å */
 #define	SAVE_N_AUTO	0
+/* Хݡѥ֡å */
+#define	SAVE_N_BUG_REPO	999
 
 /* ե̾Ĺ */
 #define	FILE_NAME_MAX_LEN	127
