@@ -25,7 +25,7 @@
 *   59 Temple Place, Suite 330, Boston, MA 02111-1307, USA
 * ؼ񤤤Ƥ
 * 
-* $Id: gmain.c,v 1.90 2007/05/05 21:16:08 bowkenken Exp $
+* $Id: gmain.c,v 1.93 2007/06/07 02:09:16 bowkenken Exp $
 ***************************************************************/
 
 /***************************************************************
@@ -107,7 +107,7 @@ char	str_usage[] = {
 	"  -U, --gui-and-cui        set GUI and CUI mode\n"
 	"  -D, --sel-graph-dir=DIR  select graphic directory:\n"
 	"                             graphic directory\n"
-	"  -S, --map-scale          set scale of map character:\n"
+	"  -S, --map-scale=N        set scale of map character:\n"
 	"                             scale(%%)\n"
 	"  -l, --language=LANGUAGE  set language:\n"
 	"                             language\n"
@@ -160,6 +160,8 @@ void	init_arg( void )
 	g_flg_use_keypad = FALSE;
 
 	g_flg_measure_clk_tck = FALSE;
+
+	g_flg_send_item_exec_turn = FALSE;
 }
 
 /***************************************************************
@@ -434,7 +436,7 @@ void	game_main( void )
 		print_msg( FLG_NULL, MSG_HINT_CANCEL_MENU_1 );
 		print_msg( FLG_NULL, MSG_HINT_CANCEL_MENU_2 );
 
-		menu_bar_load();
+		menu_load_bar();
 
 		party_exit_bar();
 	}
