@@ -25,7 +25,7 @@
 *   59 Temple Place, Suite 330, Boston, MA 02111-1307, USA
 * ؼ񤤤Ƥ
 * 
-* $Id: gmain.h,v 1.51 2007/05/12 09:20:47 bowkenken Exp $
+* $Id: gmain.h,v 1.52 2007/05/31 21:24:44 bowkenken Exp $
 ***************************************************************/
 
 #ifndef	GMAIN_H
@@ -181,4 +181,7 @@ EXTERN long	g_randm_seed_save;
 /* ǥХå⡼ */
 EXTERN bool_t	g_flg_debug;
 
+/* ƥμϤλ񤹤 */
+EXTERN bool_t	g_flg_send_item_exec_turn;
+
 #endif	/* GMAIN_H */
