@@ -46,6 +46,7 @@ void	set_menu_formation( menu_t *ls, menu_t **dflt, long mbr_n );
 char	*cb_menu_formation_sel_n( menu_t **pp, menu_t **dflt );
 char	*cb_menu_crsr( menu_t **pp, menu_t **dflt );
 char	*cb_menu_crsr_move( menu_t **pp, menu_t **dflt );
+char	*cb_menu_crsr_move_abs( menu_t **pp, menu_t **dflt );
 char	*cb_menu_crsr_move_stop( menu_t **pp, menu_t **dflt );
 void	move_crsr_abs( long x, long y );
 void	move_crsr_rel( long dx, long dy );
@@ -158,6 +159,8 @@ char	*cb_menu_user_arrange_bottom_sel( menu_t **pp, menu_t **dflt );
 char	*cb_menu_user_remove_sel( menu_t **pp, menu_t **dflt );
 char	*cb_menu_replay_load( menu_t **pp, menu_t **dflt );
 char	*cb_menu_replay_save( menu_t **pp, menu_t **dflt );
+char	*cb_menu_replay_debug( menu_t **pp, menu_t **dflt );
+char	*cb_menu_replay_bug_repo( menu_t **pp, menu_t **dflt );
 long	menu_replay_sel_load( void );
 char	*cb_menu_replay_sel_load( menu_t **pp, menu_t **dflt );
 char	*cb_menu_system( menu_t **pp, menu_t **dflt );
