@@ -25,7 +25,7 @@
 *   59 Temple Place, Suite 330, Boston, MA 02111-1307, USA
 * ؼ񤤤Ƥ
 * 
-* $Id: imenu-tab.h,v 1.4 2007/01/11 17:31:34 bowkenken Exp $
+* $Id: imenu-tab.h,v 1.7 2007/06/08 07:08:44 bowkenken Exp $
 ***************************************************************/
 
 #ifndef	IMENU_TAB_H
@@ -69,7 +69,7 @@ menu_t	ls_menu_move_crsr[] = {
 		"/cursor/move/down",
 		"<Item>",
 		'J',
-		"^N 2 j",
+		"^N s 2 j",
 		N_MSG_MENU_CRSR_MOVE_DOWN, "",
 		cb_menu_crsr_move, (void *)2,
 		FLG_NULL,
@@ -87,7 +87,7 @@ menu_t	ls_menu_move_crsr[] = {
 		"/cursor/move/left",
 		"<Item>",
 		'H',
-		"^B 4 h",
+		"^B a 4 h",
 		N_MSG_MENU_CRSR_MOVE_LEFT, "",
 		cb_menu_crsr_move, (void *)4,
 		FLG_NULL,
@@ -96,7 +96,7 @@ menu_t	ls_menu_move_crsr[] = {
 		"/cursor/move/right",
 		"<Item>",
 		'L',
-		"^F 6 l",
+		"^F d 6 l",
 		N_MSG_MENU_CRSR_MOVE_RIGHT, "",
 		cb_menu_crsr_move, (void *)6,
 		FLG_NULL,
@@ -114,7 +114,7 @@ menu_t	ls_menu_move_crsr[] = {
 		"/cursor/move/up",
 		"<Item>",
 		'K',
-		"^P 8 k",
+		"^P w 8 k",
 		N_MSG_MENU_CRSR_MOVE_UP, "",
 		cb_menu_crsr_move, (void *)8,
 		FLG_NULL,
@@ -128,6 +128,15 @@ menu_t	ls_menu_move_crsr[] = {
 		cb_menu_crsr_move, (void *)9,
 		FLG_NULL,
 	},
+	{
+		"/cursor/move/abs",
+		"<Item>",
+		'A',
+		"%",
+		N_MSG_MENU_CRSR_MOVE_ABS, "",
+		cb_menu_crsr_move_abs, NULL,
+		FLG_NULL,
+	},
 	{
 		"/cursor/move/stop",
 		"<Item>",
@@ -234,7 +243,7 @@ menu_t	ls_menu_move_crsr[] = {
 		"/cursor/center",
 		"<Item>",
 		'C',
-		"^R ^L",
+		"^L",
 		N_MSG_MENU_CRSR_CENTER, "",
 		cb_menu_crsr_center, NULL,
 		FLG_NULL,
