@@ -25,7 +25,7 @@
 *   59 Temple Place, Suite 330, Boston, MA 02111-1307, USA
 * ؼ񤤤Ƥ
 * 
-* $Id: imenu.c,v 1.27 2007/05/12 09:20:47 bowkenken Exp $
+* $Id: imenu.c,v 1.30 2007/06/07 16:38:53 bowkenken Exp $
 ***************************************************************/
 
 #define	IMENU_C
@@ -1149,6 +1149,18 @@ char	*cb_menu_crsr_move( menu_t **pp, menu_t **dflt )
 
 /**/
 
+char	*cb_menu_crsr_move_abs( menu_t **pp, menu_t **dflt )
+{
+	pos_t	pos;
+
+	if( get_key_pos( &pos ) )
+		move_crsr_abs( pos.x, pos.y );
+
+	return NULL;
+}
+
+/**/
+
 char	*cb_menu_crsr_move_stop( menu_t **pp, menu_t **dflt )
 {
 	chk_scroll( FALSE );
@@ -4111,10 +4123,10 @@ char	*cb_menu_replay_load( menu_t **pp, menu_t **dflt )
 		return STR_MENU_CANCEL;
 
 	if( load_game_replay( FALSE, n ) ){
-		reset_all_save( TRUE );
+		reset_all_save( FALSE );
 		party_exit_bar();
 
-		return "/";
+		return NULL;
 	}
 
 	return STR_MENU_CANCEL;
@@ -4132,6 +4144,30 @@ char	*cb_menu_replay_save( menu_t **pp, menu_t **dflt )
 
 /**/
 
+char	*cb_menu_replay_debug( menu_t **pp, menu_t **dflt )
+{
+	if( load_game_replay( FALSE, SAVE_N_BUG_REPO ) ){
+		reset_all_save( FALSE );
+		party_exit_bar();
+
+		return NULL;
+	}
+
+	return STR_MENU_CANCEL;
+}
+
+/**/
+
+char	*cb_menu_replay_bug_repo( menu_t **pp, menu_t **dflt )
+{
+	if( save_bug_repo_replay() )
+		return NULL;
+	else
+		return STR_MENU_CANCEL;
+}
+
+/**/
+
 long	menu_replay_sel_load( void )
 {
 	menu_t	*ls;
