@@ -25,7 +25,7 @@
 *   59 Temple Place, Suite 330, Boston, MA 02111-1307, USA
 * ؼ񤤤Ƥ
 * 
-* $Id: menu.h,v 1.36 2007/03/18 03:06:32 bowkenken Exp $
+* $Id: menu.h,v 1.39 2007/06/07 22:58:14 bowkenken Exp $
 ***************************************************************/
 
 #ifndef	MENU_H
@@ -50,15 +50,19 @@
 		'G' - '@': case 'H' - '@': case '0': case '\033'
 #define	CASE_EXEC	\
 		'5': case '.'
+#define	CASE_EXIT	\
+		'Q': case 'Q' - '@': case 'C' - '@'
+#define	CASE_SQUARE	\
+		'v': case '+'
 
 #define	CASE_CRSR_UP	\
-		'8': case 'k': case 'P' - '@'
+		'8': case 'k': case 'w': case 'P' - '@'
 #define	CASE_CRSR_DOWN	\
-		'2': case 'j': case 'N' - '@'
+		'2': case 'j': case 's': case 'N' - '@'
 #define	CASE_CRSR_LEFT	\
-		'4': case 'h': case 'B' - '@'
+		'4': case 'h': case 'a': case 'B' - '@'
 #define	CASE_CRSR_RIGHT	\
-		'6': case 'l': case 'F' - '@'
+		'6': case 'l': case 'd': case 'F' - '@'
 #define	CASE_CRSR_UP_LEFT	\
 		'7': case 'y'
 #define	CASE_CRSR_UP_RIGHT	\
@@ -109,7 +113,7 @@
 #define	MENU_SHORT_KEY_MAX_LEN	16
 
 /* ܤκʸ */
-#define	MENU_MSG_MAX_LEN	128
+#define	MENU_MSG_MAX_LEN	70
 
 /* ֡ */
 
