@@ -25,7 +25,7 @@
 *   59 Temple Place, Suite 330, Boston, MA 02111-1307, USA
 * ؼ񤤤Ƥ
 * 
-* $Id: mmenu-tab.h,v 1.18 2007/03/31 21:16:03 bowkenken Exp $
+* $Id: mmenu-tab.h,v 1.23 2007/06/08 07:08:44 bowkenken Exp $
 ***************************************************************/
 
 #ifndef	MMENU_TAB_H
@@ -317,7 +317,7 @@ menu_t	ls_menu_main[] = {
 		"/auto mark",
 		"<Branch>",
 		'A',
-		"* a",
+		"/ z",
 		N_MSG_MENU_SEL_OBJ_AUTO, "",
 		cb_menu_auto_mark, NULL,
 		FLG_NULL,
@@ -435,7 +435,7 @@ menu_t	ls_menu_main[] = {
 		"/misc/search",
 		"<Branch>",
 		'S',
-		"# ^S s",
+		"# ^S S",
 		N_MSG_MENU_SRCH, "",
 		cb_menu_srch, NULL,
 		FLG_NULL,
@@ -453,7 +453,7 @@ menu_t	ls_menu_main[] = {
 		"/misc/char data",
 		"<OpenWinItem>",
 		'D',
-		"d",
+		"C",
 		N_MSG_MENU_CHR_DATA, "",
 		cb_menu_chr_data, NULL,
 		FLG_NULL,
@@ -998,7 +998,7 @@ menu_t	ls_menu_main[] = {
 		"/misc/config/user menu select",
 		"<Branch>",
 		'U',
-		"/ x",
+		"* x",
 		N_MSG_MENU_USER, "",
 		cb_menu_user, NULL,
 		FLG_NULL,
@@ -1026,7 +1026,7 @@ menu_t	ls_menu_main[] = {
 	},
 	{
 		"/misc/system/replay/load",
-		"<Branch>",
+		"<OpenWinItem>",
 		'L',
 		"",
 		N_MSG_MENU_REPLAY_LOAD, "",
@@ -1037,11 +1037,29 @@ menu_t	ls_menu_main[] = {
 		"/misc/system/replay/save",
 		"<Item>",
 		'S',
-		"p",
+		"^R",
 		N_MSG_MENU_REPLAY_SAVE, "",
 		cb_menu_replay_save, NULL,
 		FLG_NULL,
 	},
+	{
+		"/misc/system/replay/debug",
+		"<Item>",
+		'D',
+		"",
+		N_MSG_MENU_REPLAY_DEBUG, "",
+		cb_menu_replay_debug, NULL,
+		FLG_NULL,
+	},
+	{
+		"/misc/system/replay/bug repo",
+		"<Item>",
+		'B',
+		"^D",
+		N_MSG_MENU_REPLAY_BUG_REPO, "",
+		cb_menu_replay_bug_repo, NULL,
+		FLG_NULL,
+	},
 /* replay end */
 /* wizard begin */
 	{
@@ -1104,7 +1122,7 @@ menu_t	ls_menu_main[] = {
 		'L',
 		"",
 		N_MSG_MENU_WIZARD_TEXT_LOAD, "",
-		cb_menu_load, (void *)TRUE,
+		cb_menu_load_wiz, (void *)TRUE,
 		FLG_NULL,
 	},
 	{
@@ -1113,7 +1131,7 @@ menu_t	ls_menu_main[] = {
 		'S',
 		"",
 		N_MSG_MENU_WIZARD_TEXT_SAVE, "",
-		cb_menu_save, (void *)TRUE,
+		cb_menu_save_wiz, (void *)TRUE,
 		FLG_NULL,
 	},
 /* wizard end */
@@ -1722,7 +1740,7 @@ menu_t	ls_menu_item_sel[] = {
 	},
 	{
 		"/item sel/send",
-		"<Branch>",
+		"<OpenWinItem>",
 		'S',
 		"",
 		N_MSG_MENU_ITEM_SEND, "",
@@ -1731,7 +1749,7 @@ menu_t	ls_menu_item_sel[] = {
 	},
 	{
 		"/item sel/receive",
-		"<Branch>",
+		"<OpenWinItem>",
 		'I',
 		"",
 		N_MSG_MENU_ITEM_RECEIVE, "",
