@@ -25,7 +25,7 @@
 *   59 Temple Place, Suite 330, Boston, MA 02111-1307, USA
 * ؼ񤤤Ƥ
 * 
-* $Id: mmenu.c,v 1.25 2007/05/20 15:17:08 bowkenken Exp $
+* $Id: mmenu.c,v 1.29 2007/06/07 02:09:16 bowkenken Exp $
 ***************************************************************/
 
 #define	MMENU_C
@@ -1704,11 +1704,12 @@ char	*cb_menu_item_fill_lamp( menu_t **pp, menu_t **dflt )
 		return STR_MENU_ERR;
 	}
 
-	if( set_chr_act( mbr, (act_kind_t)(long)((*pp)->arg),
+	if( !set_chr_act( mbr, (act_kind_t)(long)((*pp)->arg),
 			g_sel_item, NULL, 0, 0 ) ){
-		return NULL;
+		return STR_MENU_ERR;
 	}
-	return STR_MENU_ERR;
+
+	return NULL;
 }
 
 /**/
@@ -1765,10 +1766,14 @@ char	*cb_menu_item_send( menu_t **pp, menu_t **dflt )
 			g_sel_item, mbr2, n, 0 ) ){
 		return STR_MENU_CANCEL;
 	}
-
 	mark_mbr( mbr, mbr2, DIST_NEAR );
 
-	return NULL;
+	if( !g_flg_send_item_exec_turn ){
+		send_item( mbr );
+		clr_chr_trgt_act( mbr, TRUE );
+	}
+
+	return "/item";
 }
 
 /**/
@@ -1805,10 +1810,14 @@ char	*cb_menu_item_receive( menu_t **pp, menu_t **dflt )
 			g_sel_item, mbr, n, 0 ) ){
 		return STR_MENU_CANCEL;
 	}
-
 	mark_mbr( mbr2, mbr, DIST_NEAR );
 
-	return NULL;
+	if( !g_flg_send_item_exec_turn ){
+		receive_item( mbr2 );
+		clr_chr_trgt_act( mbr2, TRUE );
+	}
+
+	return "/item";
 }
 
 /**/
@@ -2400,7 +2409,7 @@ char	*cb_menu_fight( menu_t **pp, menu_t **dflt )
 
 /**/
 
-char	*cb_menu_load( menu_t **pp, menu_t **dflt )
+char	*cb_menu_load_wiz( menu_t **pp, menu_t **dflt )
 {
 	if( menu_load( TRUE ) )
 		reset_all_save( TRUE );
@@ -2410,7 +2419,7 @@ char	*cb_menu_load( menu_t **pp, menu_t **dflt )
 
 /**/
 
-char	*cb_menu_save( menu_t **pp, menu_t **dflt )
+char	*cb_menu_save_wiz( menu_t **pp, menu_t **dflt )
 {
 	if( menu_save( TRUE ) )
 		reset_all_save( TRUE );
@@ -2435,6 +2444,8 @@ bool_t	menu_load( bool_t flg_txt )
 
 	load_game_conf();
 	load_game_data( flg_txt, n );
+	if( n != SAVE_N_AUTO )
+		bgn_reg_replay( SAVE_N_BUG_REPO );
 
 	if( flg_txt )
 		set_flg_no_save( TRUE );
@@ -2487,6 +2498,8 @@ bool_t	menu_save_n( bool_t flg_txt, long save_n )
 	save_town();
 	save_game_conf();
 	save_game_data( flg_txt, save_n );
+	if( save_n != SAVE_N_AUTO )
+		bgn_reg_replay( SAVE_N_BUG_REPO );
 
 	if( flg_txt )
 		print_msg( FLG_NULL, MSG_MENU_SAVE_SUCCESS_TXT, save_n );
