@@ -25,7 +25,7 @@
 *   59 Temple Place, Suite 330, Boston, MA 02111-1307, USA
 * ؼ񤤤Ƥ
 * 
-* $Id: msg.c,v 1.31 2007/03/12 18:39:54 bowkenken Exp $
+* $Id: msg.c,v 1.32 2007/03/19 06:49:04 bowkenken Exp $
 ***************************************************************/
 
 /***************************************************************
@@ -172,9 +172,13 @@ void	init_msg( void )
 
 	/* Ķѿθͤ */
 
-	lang = getenv( STR_ENV_LANG );
-	if( lang == NULL )
-		lang = STR_DFLT_LANG;
+	if( g_language == NULL ){
+		lang = getenv( STR_ENV_LANG );
+		if( lang == NULL )
+			lang = STR_DFLT_LANG;
+	} else {
+		lang = g_language;
+	}
 
 	/* Ķѿǻꤵ줿μõ */
 
