@@ -25,7 +25,7 @@
 *   59 Temple Place, Suite 330, Boston, MA 02111-1307, USA
 * ؼ񤤤Ƥ
 * 
-* $Id: party.c,v 1.192 2007/05/20 14:42:05 bowkenken Exp $
+* $Id: party.c,v 1.196 2007/06/07 22:58:14 bowkenken Exp $
 ***************************************************************/
 
 #define	PARTY_C
@@ -1575,6 +1575,27 @@ void	act_phase_party( void )
 
 /**/
 
+bool_t	chk_party_no_mbr( bool_t flg_enter_bar )
+{
+	long	i;
+
+	for( i = 0; i < MBR_MAX_N; i++ ){
+		if( !chk_flg( party.mbr[i]->stat,
+				FLG_STAT_NOT_EXIST ) ){
+			return TRUE;
+		}
+	}
+
+	if( flg_enter_bar ){
+		up_dun_town();
+		party_enter_bar();
+	}
+
+	return FALSE;
+}
+
+/**/
+
 void	chk_trap_party( void )
 {
 	long	i;
@@ -1695,8 +1716,7 @@ void	die_mbr( mbr_t *mbr, bool_t flg_chk_game_over )
 		print_msg( FLG_MSG_NO_MORE_PREV, MSG_S, MSG_GAME_OVER );
 		while( 1 ){
 			switch( get_key( g_flg_clr_key_buf ) ){
-			case 'C' - '@':
-			case 'Q' - '@':
+			case CASE_EXIT:
 				exit_game( EXIT_SUCCESS );
 			}
 		}
@@ -2210,12 +2230,10 @@ void	remove_mbr( mbr_t *mbr )
 	mbr_n = mbr->mbr_n;
 	ls_mbr_n = mbr->ls_mbr_n;
 
-	/* ʸ */
+	/**/
 
 	remove_cast_tab( ls_mbr_n );
-
-	/* item */
-
+	remove_auto_mark_mbr( ls_mbr_n );
 	remove_mbr_del_item( ls_mbr_n );
 
 	/* ls_mbr */
