@@ -25,7 +25,7 @@
 *   59 Temple Place, Suite 330, Boston, MA 02111-1307, USA
 * ؼ񤤤Ƥ
 * 
-* $Id: party.h,v 1.18 2007/03/19 12:45:00 bowkenken Exp $
+* $Id: party.h,v 1.19 2007/06/01 01:08:53 bowkenken Exp $
 ***************************************************************/
 
 #ifndef	PARTY_H
@@ -35,10 +35,19 @@
 
 #include	"chr.h"
 
-/**/
-
 /* С */
 
+enum {
+	LS_MBR_N_BLADE,
+	LS_MBR_N_DRANK,
+	LS_MBR_N_ELSIE,
+	LS_MBR_N_CECILE,
+	LS_MBR_N_HALLE,
+	LS_MBR_N_BEAUT,
+	LS_MBR_N_GOKOU,
+	LS_MBR_N_EYE,
+};
+
 #define	MBR_MAX_N	6	/*  */
 #define	MBR_N_NOT_JOIN	(-1)	/* ѡƥ˲ääƤʤ */
 #define	MBR_NO_POS	(-1)	/* ե᡼ζ */
