@@ -25,7 +25,7 @@
 *   59 Temple Place, Suite 330, Boston, MA 02111-1307, USA
 * ؼ񤤤Ƥ
 * 
-* $Id: pet.c,v 1.55 2007/05/26 12:17:19 bowkenken Exp $
+* $Id: pet.c,v 1.56 2007/05/31 18:35:21 bowkenken Exp $
 ***************************************************************/
 
 /***************************************************************
@@ -246,6 +246,8 @@ void	appear_pet( pet_t *p )
 		return;
 	}
 
+	chk_pet_owner( p );
+
 	if( p->owner == NULL ){
 		x = MAP_MAX_X / 2;
 		y = MAP_MAX_Y / 2;
@@ -273,6 +275,7 @@ void	move_phase_all_pet( void )
 		if( pp == NULL )
 			continue;
 
+		chk_pet_owner( pp );
 		set_act_mnstr( pp );
 		move_phase_chr( pp );
 	}
@@ -308,6 +311,7 @@ void	set_act_pet_std( pet_t *p )
 	if( p == NULL )
 		return;
 
+	chk_pet_owner( p );
 	pet_mark_std( p );
 
 	if( (p->trgt.kind == TRGT_KIND_MNSTR)
@@ -490,6 +494,9 @@ void	clr_pet_owner( pet_t *p )
 	party_t	*pty = get_party();
 	long	i;
 
+	if( p == NULL )
+		return;
+
 	for( i = 0; i < MBR_MAX_N; i++ ){
 		chr_t	*chr;
 
@@ -498,12 +505,36 @@ void	clr_pet_owner( pet_t *p )
 				FLG_STAT_NOT_EXIST | FLG_STAT_DEAD ) ){
 			continue;
 		}
+		if( chr->mbr_n == MBR_N_NOT_JOIN )
+			continue;
 
 		p->owner = chr;
 		break;
 	}
 }
 
+/***************************************************************
+* ڥåȤλ
+* pet_t *p : ڥå
+***************************************************************/
+
+void	chk_pet_owner( pet_t *p )
+{
+	if( p == NULL )
+		return;
+
+	if( p->owner == NULL )
+		clr_pet_owner( p );
+
+	if( (p->owner != NULL) && chk_flg_or( p->owner->stat,
+			FLG_STAT_NOT_EXIST | FLG_STAT_DEAD ) ){
+		clr_pet_owner( p );
+	}
+
+	if( (p->owner != NULL) && (p->owner->mbr_n == MBR_N_NOT_JOIN) )
+		clr_pet_owner( p );
+}
+
 /***************************************************************
 * ڥåȤѡƥ˲ä뤫Ĵ٤
 * pet_t *p : ڥå
