@@ -25,7 +25,7 @@
 *   59 Temple Place, Suite 330, Boston, MA 02111-1307, USA
 * ؼ񤤤Ƥ
 * 
-* $Id: spell-tab.h,v 1.14 2007/01/11 17:31:35 bowkenken Exp $
+* $Id: spell-tab.h,v 1.15 2007/06/01 01:08:53 bowkenken Exp $
 ***************************************************************/
 
 #ifndef	SPELL_TAB_H
@@ -2548,6 +2548,15 @@ menu_t	ls_menu_spell_extent[] = {
 		cb_menu_spell_extent, (void *)EXTENT_KIND_HALF,
 		FLG_NULL,
 	},
+	{
+		"/spell extent/double",
+		"<Item>",
+		'D',
+		"",
+		N_MSG_MENU_SPELL_EXTENT_DOUBLE, "",
+		cb_menu_spell_extent, (void *)EXTENT_KIND_DOUBLE,
+		FLG_NULL,
+	},
 	{
 		"",
 		"",
