@@ -25,7 +25,7 @@
 *   59 Temple Place, Suite 330, Boston, MA 02111-1307, USA
 * ؼ񤤤Ƥ
 * 
-* $Id: spell.c,v 1.163 2007/05/12 09:52:17 bowkenken Exp $
+* $Id: spell.c,v 1.164 2007/06/01 01:08:53 bowkenken Exp $
 ***************************************************************/
 
 #define	SPELL_C
@@ -59,17 +59,6 @@
 
 #define	BAR_LIMIT_LEV	10
 
-enum {
-	LS_MBR_N_BLADE,
-	LS_MBR_N_DRANK,
-	LS_MBR_N_ELSIE,
-	LS_MBR_N_CECILE,
-	LS_MBR_N_HALLE,
-	LS_MBR_N_BEAUT,
-	LS_MBR_N_GOKOU,
-	LS_MBR_N_EYE,
-};
-
 /**/
 
 static cast_tab_t	cast_tab[LS_MBR_MAX_N][SPELL_KIND_MAX_N];
@@ -489,6 +478,11 @@ char	*cb_menu_spell( menu_t **pp, menu_t **dflt )
 	else
 		set_flg_menu( ls, "half", FLG_MENU_HIDDEN );
 
+	if( chk_flg( g_sel_spell->flg_extent, FLG_EXTENT_DOUBLE ) )
+		clr_flg_menu( ls, "double", FLG_MENU_HIDDEN );
+	else
+		set_flg_menu( ls, "double", FLG_MENU_HIDDEN );
+
 	*pp = ls;
 	*dflt = g_dflt_spell_extent[g_sel_mbr->ls_mbr_n][g_sel_spell_abl];
 
@@ -679,6 +673,11 @@ void	chr_cast_spell( chr_t *chr, spell_tab_t *tab, const char *fmt )
 		mp /= 2;
 		resi /= 2;
 		break;
+	case EXTENT_KIND_DOUBLE:
+		hp *= 2;
+		mp *= 2;
+		resi *= 2;
+		break;
 	}
 	if( (tab->hp > 0) && (hp < 1) )
 		hp = 1;
@@ -796,6 +795,9 @@ void	chr_cast_spell( chr_t *chr, spell_tab_t *tab, const char *fmt )
 	case EXTENT_KIND_HALF:
 		chr_cast_spell_normal( chr, FALSE, tab, (rate_t)50 );
 		break;
+	case EXTENT_KIND_DOUBLE:
+		chr_cast_spell_normal( chr, FALSE, tab, (rate_t)200 );
+		break;
 	}
 
 	fx_cast_spell( chr, tab );
