@@ -25,7 +25,7 @@
 *   59 Temple Place, Suite 330, Boston, MA 02111-1307, USA
 * ؼ񤤤Ƥ
 * 
-* $Id: tmenu.c,v 1.112 2007/05/16 09:37:19 bowkenken Exp $
+* $Id: tmenu.c,v 1.115 2007/06/07 02:09:16 bowkenken Exp $
 ***************************************************************/
 
 #define	TMENU_C
@@ -33,6 +33,9 @@
 
 /**/
 
+/* ˡȤʤƤ⥮ɤ뤫? */
+#define	FLG_CAN_ENTER_MAGIC_GUILD_NOT_LEARNED	TRUE
+
 /* ƥŹä˼̤뤫? */
 #define	FLG_IDENTIFY_ITEM_SALE	FALSE
 
@@ -2014,6 +2017,9 @@ char	*cb_menu_bar_arrange( long d )
 	ls_mbr = get_ls_mbr();
 	trgt_ls_mbr_n = g_sel_ls_mbr->ls_mbr_n;
 
+	arrange_cast_tab( trgt_ls_mbr_n, d );
+	arrange_auto_mark_mbr( trgt_ls_mbr_n, d );
+
 	tmp_mbr = g_sel_ls_mbr;
 	if( d <= -1 ){
 		for( i = trgt_ls_mbr_n - 1; i >= 0; i-- ){
@@ -2042,8 +2048,6 @@ char	*cb_menu_bar_arrange( long d )
 		g_sel_ls_mbr = ls_mbr[i - 1];
 	}
 
-	arrange_cast_tab( trgt_ls_mbr_n, d );
-
 	return "/bar/form/edit member/edit member";
 }
 
@@ -2628,36 +2632,39 @@ void	menu_edit_class_inc_abl(
 
 /**/
 
-char	*cb_menu_bar_load( menu_t **pp, menu_t **dflt )
+char	*cb_menu_load_bar( menu_t **pp, menu_t **dflt )
 {
-	menu_bar_load();
+	menu_load_bar();
+
+//@@@
+	return NULL;
+	return "/";
+	return "/bar";
+}
+
+/**/
+
+char	*cb_menu_save_bar( menu_t **pp, menu_t **dflt )
+{
+	menu_save_bar();
 
 	return NULL;
 }
 
 /**/
 
-char	*cb_menu_bar_save( menu_t **pp, menu_t **dflt )
-{
-	menu_bar_save();
-
-	return NULL;
-}
-
-/**/
-
-void	menu_bar_load( void )
+void	menu_load_bar( void )
 {
 	if( menu_load( FALSE ) )
-		reset_all_save( TRUE );
+		reset_all_save( FALSE );
 }
 
 /**/
 
-void	menu_bar_save( void )
+void	menu_save_bar( void )
 {
 	if( menu_save( FALSE ) )
-		reset_all_save( TRUE );
+		reset_all_save( FALSE );
 }
 
 /**/
@@ -2769,7 +2776,7 @@ char	*cb_menu_magic_guild_init( menu_t **pp, menu_t **dflt )
 {
 	menu_t	*ls, *p;
 	unsigned char	key;
-	bool_t	flg;
+	bool_t	flg_no_enter;
 	gold_t	gold;
 	long	i;
 
@@ -2839,39 +2846,42 @@ char	*cb_menu_magic_guild_init( menu_t **pp, menu_t **dflt )
 		}
 	}
 
-	flg = FALSE;
+	if( !FLG_CAN_ENTER_MAGIC_GUILD_NOT_LEARNED ){
+		flg_no_enter = FALSE;
 
-	if( get_lev( g_sel_mbr, ABL_KIND_MAG ) > 0 ){
-		clr_flg_menu( ls, "MAG", FLG_MENU_HIDDEN );
-		flg = TRUE;
-	} else {
-		set_flg_menu( ls, "MAG", FLG_MENU_HIDDEN );
-	}
+		if( get_lev( g_sel_mbr, ABL_KIND_MAG ) > 0 ){
+			clr_flg_menu( ls, "MAG", FLG_MENU_HIDDEN );
+			flg_no_enter = TRUE;
+		} else {
+			set_flg_menu( ls, "MAG", FLG_MENU_HIDDEN );
+		}
 
-	if( get_lev( g_sel_mbr, ABL_KIND_SOR ) > 0 ){
-		clr_flg_menu( ls, "SOR", FLG_MENU_HIDDEN );
-		flg = TRUE;
-	} else {
-		set_flg_menu( ls, "SOR", FLG_MENU_HIDDEN );
-	}
+		if( get_lev( g_sel_mbr, ABL_KIND_SOR ) > 0 ){
+			clr_flg_menu( ls, "SOR", FLG_MENU_HIDDEN );
+			flg_no_enter = TRUE;
+		} else {
+			set_flg_menu( ls, "SOR", FLG_MENU_HIDDEN );
+		}
 
-	if( get_lev( g_sel_mbr, ABL_KIND_ENC ) > 0 ){
-		clr_flg_menu( ls, "ENC", FLG_MENU_HIDDEN );
-		flg = TRUE;
-	} else {
-		set_flg_menu( ls, "ENC", FLG_MENU_HIDDEN );
-	}
+		if( get_lev( g_sel_mbr, ABL_KIND_ENC ) > 0 ){
+			clr_flg_menu( ls, "ENC", FLG_MENU_HIDDEN );
+			flg_no_enter = TRUE;
+		} else {
+			set_flg_menu( ls, "ENC", FLG_MENU_HIDDEN );
+		}
 
-	if( get_lev( g_sel_mbr, ABL_KIND_SUM ) > 0 ){
-		clr_flg_menu( ls, "SUM", FLG_MENU_HIDDEN );
-		flg = TRUE;
-	} else {
-		set_flg_menu( ls, "SUM", FLG_MENU_HIDDEN );
-	}
+		if( get_lev( g_sel_mbr, ABL_KIND_SUM ) > 0 ){
+			clr_flg_menu( ls, "SUM", FLG_MENU_HIDDEN );
+			flg_no_enter = TRUE;
+		} else {
+			set_flg_menu( ls, "SUM", FLG_MENU_HIDDEN );
+		}
 
-	if( !flg ){
-		print_msg( FLG_MSG_ERR, MSG_ERR_SPELL, g_sel_mbr->name );
-		return STR_MENU_CANCEL;
+		if( !flg_no_enter ){
+			print_msg( FLG_MSG_ERR, MSG_ERR_SPELL,
+					g_sel_mbr->name );
+			return STR_MENU_CANCEL;
+		}
 	}
 
 	return NULL;
