@@ -25,7 +25,7 @@
 *   59 Temple Place, Suite 330, Boston, MA 02111-1307, USA
 * ؼ񤤤Ƥ
 * 
-* $Id: town.c,v 1.126 2007/05/16 09:37:19 bowkenken Exp $
+* $Id: town.c,v 1.127 2007/06/07 02:09:16 bowkenken Exp $
 ***************************************************************/
 
 #define	TOWN_C
@@ -1441,20 +1441,29 @@ void	party_exit_shop( long dr_n )
 
 /**/
 
+void	party_enter_bar( void )
+{
+	door_t	*dr;
+
+	dr = get_shop_door( SHOP_N_BAR );
+	if( dr == NULL )
+		return;
+
+	open_door_shop( dr->n );
+	enter_shop();
+}
+
+/**/
+
 void	party_exit_bar( void )
 {
 	door_t	*dr;
 
 	dr = get_shop_door( SHOP_N_BAR );
-	if( dr != NULL ){
-#if	1
-//@@@
-		party_exit_shop( dr->n );
-#else
-		open_door_shop( dr->n );
-		exec_all_phase();
-#endif
-	}
+	if( dr == NULL )
+		return;
+
+	party_exit_shop( dr->n );
 }
 
 /**/
