@@ -25,7 +25,7 @@
 *   59 Temple Place, Suite 330, Boston, MA 02111-1307, USA
 * ؼ񤤤Ƥ
 * 
-* $Id: trap.c,v 1.60 2007/01/11 17:31:35 bowkenken Exp $
+* $Id: trap.c,v 1.62 2007/03/31 21:16:03 bowkenken Exp $
 ***************************************************************/
 
 /***************************************************************
@@ -220,12 +220,14 @@ trap_t	*make_trap( long x, long y, long dun_lev )
 	for( i = LOOP_MAX_100; i > 0; i-- ){
 		n = randm( trap_tab_max_n );
 
-#if	defined( DEBUG ) && defined( D_TEST_TRAP_KIND )
-		if( D_TEST_TRAP_KIND != TRAP_KIND_NULL ){
-			if( trap_tab[n].kind == D_TEST_TRAP_KIND ){
-				break;
-			} else {
-				continue;
+#ifdef	D_TEST_TRAP_KIND
+		if( g_flg_debug ){
+			if( D_TEST_TRAP_KIND != TRAP_KIND_NULL ){
+				if( trap_tab[n].kind == D_TEST_TRAP_KIND ){
+					break;
+				} else {
+					continue;
+				}
 			}
 		}
 #endif
@@ -660,7 +662,8 @@ void	caught_trap( trap_t *trap, chr_t *chr )
 				_100_PERCENT );
 		break;
 	case TRAP_KIND_TELEPORT_PARTY:
-		teleport_party();
+		if( (chr->kind == CHR_KIND_MBR) || is_pet( chr ) )
+			teleport_party();
 		break;
 	case TRAP_KIND_TELEPORT:
 		teleport_chr( chr );
