@@ -25,7 +25,7 @@
 *   59 Temple Place, Suite 330, Boston, MA 02111-1307, USA
 * ؼ񤤤Ƥ
 * 
-* $Id: ver.h,v 1.47 2007/02/06 10:53:52 bowkenken Exp $
+* $Id: ver.h,v 1.49 2007/03/10 19:42:20 bowkenken Exp $
 ***************************************************************/
 
 #ifndef	VER_H
@@ -47,10 +47,13 @@
 #define	STR_HANDLE_1	"BowKenKen"
 
 #define	STR_TITLE_2	"Graphic Design"
-#define	STR_HANDLE_2	"[RPG DOT], Whitecat, REFMAP, kokusi(yujyu)"
+#define	STR_HANDLE_2	"[RPG DOT], Whitecat, REFMAP"
+
+#define	STR_TITLE_3	" "
+#define	STR_HANDLE_3	"and kokusi(yujyu)"
 
 #define	STR_TITLE_THANKS	"Special Thanks"
-#define	STR_HANDLE_THANKS	"TeaMiKL, nnn and you"
+#define	STR_HANDLE_THANKS	"t-oikawa, TeaMiKL, nnn and you"
 
 #define	STR_FMT_COPYRIGHT	\
 		"--------------------------------" \
@@ -64,6 +67,7 @@
 		"%20s  %s\n" \
 		"%20s  %s\n" \
 		"%20s  %s\n" \
+		"%20s  %s\n" \
 		"--------------------------------" \
 		"--------------------------------\n" \
 		""
@@ -75,6 +79,7 @@
 		STR_E_MAIL, \
 		STR_TITLE_1, STR_HANDLE_1, \
 		STR_TITLE_2, STR_HANDLE_2, \
+		STR_TITLE_3, STR_HANDLE_3, \
 		STR_TITLE_THANKS, STR_HANDLE_THANKS
 
 #endif	/* VER_H */
